==> reverie_dreams-0.4.3%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/template/DanmakuShapeCreatorItem.java <==
package cc.thonly.reverie_dreams.item.template;

import cc.thonly.reverie_dreams.component.ModDataComponentTypes;
import cc.thonly.reverie_dreams.gui.DanmakuShapeEditGui;
import cc.thonly.reverie_dreams.recipe.ItemStackWrapper;
import eu.pb4.sgui.api.gui.SimpleGui;
import java.util.function.Consumer;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3222;

public class DanmakuShapeCreatorItem extends class_1792 {
    public DanmakuShapeCreatorItem(class_1793 settings) {
        super(settings.method_7889(4));
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        if (!world.field_9236 && user instanceof class_3222 player) {
            SimpleGui gui = new DanmakuShapeEditGui(player, user.method_5998(hand), hand);
            gui.open();
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }

//    @Override
//    public void appendTooltip(ItemStack stack, TooltipContext context, TooltipDisplayComponent displayComponent, Consumer<Text> textConsumer, TooltipType type) {
//        super.appendTooltip(stack, context, displayComponent, textConsumer, type);
//        ItemStackWrapper itemStackWrapper = stack.getOrDefault(ModDataComponentTypes.Danmaku.SHAPE, ItemStackWrapper.of(Items.AIR));
//        ItemStack itemStack = itemStackWrapper.getItemStack();
//        textConsumer.accept(Text.empty().append(Text.translatable("item.tooltip.shape")).append(itemStack.getName()));
//    }

    @Override
    public boolean method_7886(class_1799 stack) {
        ItemStackWrapper itemStackWrapper = stack.method_58694(ModDataComponentTypes.Danmaku.SHAPE);
        return itemStackWrapper != null;
    }
}

==> reverie_dreams-0.4.7%2B1.21.7%2Bbeta-sources.jar: cc/thonly/reverie_dreams/item/template/DanmakuShapeCreatorItem.java <==
package cc.thonly.reverie_dreams.item.template;

import cc.thonly.reverie_dreams.registry.content.component.RDDataComponentTypes;
import cc.thonly.reverie_dreams.gui.DanmakuShapeEditGui;
import cc.thonly.reverie_dreams.recipe.ItemStackWrapper;
import eu.pb4.sgui.api.gui.SimpleGui;
import net.minecraft.class_1268;
import net.minecraft.class_1269;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1937;
import net.minecraft.class_3222;

public class DanmakuShapeCreatorItem extends class_1792 {
    public DanmakuShapeCreatorItem(class_1793 settings) {
        super(settings.method_7889(4));
    }

    @Override
    public class_1269 method_7836(class_1937 world, class_1657 user, class_1268 hand) {
        if (!world.field_9236 && user instanceof class_3222 player) {
            SimpleGui gui = new DanmakuShapeEditGui(player, user.method_5998(hand), hand);
            gui.open();
            return class_1269.field_52422;
        }
        return class_1269.field_5812;
    }

//    @Override
//    public void appendTooltip(ItemStack stack, TooltipContext context, TooltipDisplayComponent displayComponent, Consumer<Text> textConsumer, TooltipType type) {
//        super.appendTooltip(stack, context, displayComponent, textConsumer, type);
//        ItemStackWrapper itemStackWrapper = stack.getOrDefault(ModDataComponentTypes.Danmaku.SHAPE, ItemStackWrapper.of(Items.AIR));
//        ItemStack itemStack = itemStackWrapper.getItemStack();
//        textConsumer.accept(Text.empty().append(Text.translatable("item.tooltip.shape")).append(itemStack.getName()));
//    }

    @Override
    public boolean method_7886(class_1799 stack) {
        ItemStackWrapper itemStackWrapper = stack.method_58694(RDDataComponentTypes.DANMAKU_SHAPE);
        return itemStackWrapper != null;
    }
}
